@@ -6,11 +6,12 @@ from sqlglot.tokens import Tokenizer, TokenType
 
 
 class ClickHouse(Dialect):
-    identifiers = ['"', "`"]
     normalize_functions = None
     null_ordering = "nulls_are_last"
 
     class Tokenizer(Tokenizer):
+        IDENTIFIERS = ['"', "`"]
+
         KEYWORDS = {
             **Tokenizer.KEYWORDS,
             "NULLABLE": TokenType.NULLABLE,
@@ -35,6 +36,11 @@ class ClickHouse(Dialect):
     class Generator(Generator):
         STRUCT_DELIMITER = ("(", ")")
 
+        TYPE_MAPPING = {
+            **Generator.TYPE_MAPPING,
+            exp.DataType.Type.NULLABLE: "Nullable",
+        }
+
         TRANSFORMS = {
             **Generator.TRANSFORMS,
             exp.Array: inline_array_sql,
